#include <QtCore>
#include <package.h>
#include <repo.h>
#include <versionchecker.h>
#include <globals.h>

#ifndef PACKAGEDB_H
#define PACKAGEDB_H

class PackageDB
{
public:
    PackageDB();
    bool statusOK;
    QString statusString;

    Repo rosaRepo;
    Repo cookerRepo;
    Repo mageiaRepo;
    Repo fedoraRepo;
    Repo pclinuxosRepo;
    Repo sisyphusRepo;
    Repo opensuseRepo;
    Repo gentooRepo;
    Repo debianRepo;
    Repo ubuntuRepo;

    QList<Package> newPackagesList;
    QList<Package> fullPackagesList;
    QList<Package> blackList;
    QList<Package> urlsList;
    int updateLists();
    void initDB();
    void generateHTMLTable(Repo refRepo, Repo compRepo, int mode = REPORT_ALL);
    void search(QString packageName);
    void displayList(QList<Package> &packageList);

private:
    VersionChecker checker;
    QDir configPath;
    QString getPackageSource(QString packageName, QList<Package> &packageList);
    QString getPackageSourceUrl(QString packageName, QList<Package> &packageList);
    QString getPackageVersion(QString packageName, QList<Package> &packageList);
    QString getUpdatedSourceUrl(QString inFileName, Package inPackage);
    QString getPackageHomepage(QString packageName);
    void updateListSourceUrls(QString inFileName, QList<Package> &packageList);
    void removeOlds(QList<Package> &packageList);
    bool readPackages(QString inFileName, QList<Package> &packageList, QString packageSource);
    bool readBlacklist();
    bool isBlacklisted(Package inPackage);
    bool readUrls();
};

#endif // PACKAGEDB_H
